aboutsummaryrefslogtreecommitdiffstats
path: root/ram
diff options
context:
space:
mode:
authorRangi42 <remy.oukaour+rangi42@gmail.com>2023-11-20 18:53:23 -0500
committerRangi42 <remy.oukaour+rangi42@gmail.com>2023-11-20 18:53:23 -0500
commit77887be2512b4b8af688dc4552bdb4490d35e65b (patch)
tree126dbe7e52876690b9970869c554de83ec093e9c /ram
parentAdd `bigdw` and `dc` data macros (diff)
downloadpokeyellow-77887be2512b4b8af688dc4552bdb4490d35e65b.tar.gz
pokeyellow-77887be2512b4b8af688dc4552bdb4490d35e65b.tar.xz
pokeyellow-77887be2512b4b8af688dc4552bdb4490d35e65b.zip
Identify `wSavedCoordIndex` and its other usages
Diffstat (limited to 'ram')
-rw-r--r--ram/wram.asm13
1 files changed, 8 insertions, 5 deletions
diff --git a/ram/wram.asm b/ram/wram.asm
index 8c246b8a..32749db3 100644
--- a/ram/wram.asm
+++ b/ram/wram.asm
@@ -576,10 +576,10 @@ wFilteredBagItemsCount:: db
wSimulatedJoypadStatesIndex:: db
; written to but nothing ever reads it
-wWastedByteCD39:: db
+wUnusedCD39:: db
; written to but nothing ever reads it
-wWastedByteCD3A:: db
+wUnusedCD3A:: db
; mask indicating which real button presses can override simulated ones
; XXX is it ever not 0?
@@ -979,7 +979,10 @@ wBattleResult:: db
; bit 0: if set, DisplayTextID automatically draws a text box
wAutoTextBoxDrawingControl:: db
-wcf0d:: db ; used with some overworld scripts (not exactly sure what it's used for)
+; used in some overworld scripts to vary scripted movement
+wSavedCoordIndex::
+wOakWalkedToPlayer::
+wNextSafariZoneGateScript:: db
; used in CheckForTilePairCollisions2 to store the tile the player is on
wTilePlayerStandingOn:: db
@@ -1913,8 +1916,8 @@ wMissableObjectFlagsEnd::
ds 7
-; temp copy of SPRITESTATEDATA1_IMAGEINDEX (used for sprite facing/anim)
-wSpriteImageIndexBackup:: db
+; saved copy of SPRITESTATEDATA1_IMAGEINDEX (used for sprite facing/anim)
+wSavedSpriteImageIndex:: db
; each entry consists of 2 bytes
; * the sprite ID (depending on the current map)